#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: email-validate
version: 2.2.0
id: email-validate-2.2.0-ae0abf871e42011586547a4481d3ce69
key: email_FBskWExVbGsKLO6Poucc1c
license: BSD3
maintainer: George Pollard <porges@porg.es>
stability: experimental
homepage: http://porg.es/blog/email-address-validation-simpler-faster-more-correct
synopsis: Validating an email address string against RFC 5322
description:
    Validating an email address string against RFC 5322
category: Text
author: George Pollard <porges@porg.es>
exposed: True
exposed-modules:
    Text.Email.Validate Text.Email.Parser
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/email-validate-2.2.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/email-validate-2.2.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/email-validate-2.2.0
hs-libraries: HSemail-validate-2.2.0-FBskWExVbGsKLO6Poucc1c
depends:
    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
haddock-interfaces: /usr/share/doc/haskell-email-validate/html/email-validate.haddock
haddock-html: /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
